@@ -1,3 +1,4 @@
+from .copy import copy_vds  # NOQA
 from .enums import AccessModes, BrickSizes, Components, Dimensions, Formats, MetadataTypes  # NOQA
-from .utils import METADATATYPE2GETFUNCTION, METADATATYPE2SETFUNCTION  # NOQA
+from .utils import METADATATYPE_TO_OVDS_GET_FUNCTION, METADATATYPE_TO_OVDS_SET_FUNCTION  # NOQA
 from .writing import create_vds, write_pages  # NOQA
